--[[
Name: LibStatsPane-1.0
Description: A library to assist in adding custom data in the character stats pane.
Revision: $Revision: 2 $
Author: Whitetooth
Email: hotdogee [at] gmail [dot] com
Last Update: $Date: 2010-10-09 18:15:54 +0000 (Sat, 09 Oct 2010) $
Website:
Documentation:
SVN: $URL $
Dependencies: UTF8
License: LGPL v3
Features:
]]

local MAJOR = "LibStatsPane-1.0"
local MINOR = "$Revision: 2 $"

local lib = LibStub:NewLibrary(MAJOR, MINOR)
if not lib then return end

local function validate(pane)
  if type(pane) ~= "table" then
    error("pane should be a table: "..tostring(pane))
  elseif type(pane.Category) ~= "string" then
    error("pane.Category should be a string: "..tostring(pane.Category))
  elseif type(pane.StatInfo) ~= "table" then
    error("pane.StatInfo should be a table: "..tostring(pane.StatInfo))
  else
    for k, v in pairs(pane.StatInfo) do
      if type(v) ~= "table" then
        error("pane.StatInfo."..k.." should be a table: "..tostring(v))
      elseif type(v.id) ~= "string" then
        error("pane.StatInfo."..k..".id should be a string: "..tostring(v.id))
      elseif type(v.updateFunc) ~= "function" then
        error("pane.StatInfo."..k..".updateFunc should be a function: "..tostring(v.updateFunc))
      end
    end
  end
  return true
end

function lib:AddPane(pane)
  -- Validate
  if not validate(pane) then return end
  -- Setup veriables needed for initialization
  tinsert(PAPERDOLL_STATCATEGORY_DEFAULTORDER, pane.Category)
  _G["STAT_CATEGORY_"..pane.Category] = pane.Category
  local catId = #PAPERDOLL_STATCATEGORY_DEFAULTORDER
  PAPERDOLL_STATCATEGORIES[pane.Category] = {
    id = catId,
    stats = {},
  }
  for k, v in ipairs(pane.StatInfo) do
    tinsert(PAPERDOLL_STATCATEGORIES[pane.Category].stats, v.id)
    PAPERDOLL_STATINFO[v.id] = {
      updateFunc = v.updateFunc,
    }
  end
  -- Create CharacterStatsPaneCategory
  CreateFrame("Frame", "CharacterStatsPaneCategory"..catId, CharacterStatsPaneScrollChild, "StatGroupTemplate")
end